@@ -50,7 +50,8 @@ Socket::Socket(Thread *thread, const QString &protocol)
    m_cmdData(0),
    m_thread(thread),
    m_transferBytes(0),
-   m_speedLimiter(new SpeedLimiter(this)),
+   m_speedLastTime(0),
+   m_speedLastBytes(0),
    m_protocol(protocol),
    m_currentCommand(Commands::CmdNone),
    m_errorReporting(true),
@@ -62,7 +63,6 @@ Socket::Socket(Thread *thread, const QString &protocol)
 Socket::~Socket()
 {
   delete m_remoteEncoding;
-  delete m_speedLimiter;
   
   if (m_connectionRetry)
     delete m_connectionRetry;
@@ -364,6 +364,9 @@ filesize_t Socket::getTransferSpeed()
   if (timeDelta == 0)
     return 0;
   
+  if (m_speedLastBytes > m_transferBytes)
+    m_speedLastBytes = 0;
+  
   filesize_t speed = (m_transferBytes - m_speedLastBytes)/(time(0) - m_speedLastTime);
   
   m_speedLastBytes = m_transferBytes;
@@ -491,7 +494,6 @@ public:
           socket()->setErrorReporting(false);
           
           // Issue a directory listing on the given URL
-          currentDirectory = socket()->getCurrentDirectory();
           currentState = SentList;
           socket()->protoList(currentDirectory);
           break;
@@ -505,9 +507,9 @@ public:
           
           // Empty listing, we are done
           if (currentEntry == currentList.end()) {
-            if (socket()->isChained())
+            if (socket()->isChained()) {
               socket()->resetCommandClass();
-            else {
+            } else {
               // We are the toplevel scan command
               markClean();
               
@@ -523,13 +525,10 @@ public:
           if ((*currentEntry).isDirectory()) {
             // A directory entry
             DirectoryTree *tree = currentTree->addDirectory(*currentEntry);
-            
-            // A directory, chain another scan command
             currentState = ScannedDir;
-            socket()->setCurrentDirectory(currentDirectory + "/" + (*currentEntry).filename());
             
-            // Chain manually, since we need to set the currentTree parameter
             FtpCommandScan *scan = new FtpCommandScan(socket());
+            scan->currentDirectory = currentDirectory + "/" + (*currentEntry).filename();
             scan->currentTree = tree;
             socket()->addToCommandChain(scan);
             socket()->nextCommandAsync();
@@ -544,9 +543,9 @@ public:
           
           if (++currentEntry == currentList.end()) {
             // We are done
-            if (socket()->isChained())
+            if (socket()->isChained()) {
               socket()->resetCommandClass();
-            else {
+            } else {
               // We are the toplevel scan command
               markClean();
               
@@ -567,11 +566,10 @@ void Socket::protoScan(const KURL &path)
 {
   emitEvent(Event::EventMessage, i18n("Starting recursive directory scan..."));
   
-  setCurrentDirectory(path.path());
-  
   // We have to create a new command class manually, since we need to set the
   // currentTree parameter
   FtpCommandScan *scan = new FtpCommandScan(this);
+  scan->currentDirectory = path.path();
   scan->currentTree = new DirectoryTree(DirectoryEntry());
   m_cmdData = scan;
   m_cmdData->process();
