@@ -423,15 +423,20 @@ void Actions::slotProps()
   }
 
   // Show the dialog
+  KPropertiesDialog *propsDialog;
+  
   if (item->isLocalFile()) {
-    KPropertiesDialog *propsDialog = new KPropertiesDialog(item);
-    propsDialog->exec();
+    if (selectedItems->count() == 0)
+      propsDialog = new KPropertiesDialog(item);
+    else
+      propsDialog = new KPropertiesDialog(*selectedItems);
   } else {
-    KPropertiesDialog *propsDialog = new KPropertiesDialog(item->name());
-    propsDialog->insertPlugin(new KFTPWidgets::Browser::PropsPlugin(propsDialog, item));
-    propsDialog->insertPlugin(new KFTPWidgets::Browser::PermissionsPropsPlugin(propsDialog, item, m_view->getSession()));
-    propsDialog->exec();
+    propsDialog = new KPropertiesDialog(item->name());
+    propsDialog->insertPlugin(new KFTPWidgets::Browser::PropsPlugin(propsDialog, *selectedItems));
+    propsDialog->insertPlugin(new KFTPWidgets::Browser::PermissionsPropsPlugin(propsDialog, *selectedItems, m_view->getSession()));
   }
+  
+  propsDialog->exec();
 }
 
 void Actions::addPriorityItems(int priority)
